use crate::prelude::*;

pub fn setup(
    mut commands: Commands,
    asset_server: Res<AssetServer>,
    mut materials: ResMut<Assets<ColorMaterial>>,
) {
    // Camera
    commands.spawn_bundle(OrthographicCameraBundle::new_2d());

    // Map
    let grass_material = materials.add(asset_server.load("grass.png").into());
    let tile_size = Vec2::new(32.0, 32.0);
    let sprite = Sprite::new(tile_size);
    let map_size = Vec2::new(80.0, 50.0);
    let half_x = (map_size.x / 2.0) as i32;
    let half_y = (map_size.y / 2.0) as i32;

    for y in -half_y..half_y {
        for x in -half_x..half_x {
            let position = Vec2::new(x as f32, y as f32);
            let translation = (position * tile_size).extend(0.0);

            commands.spawn_bundle(SpriteBundle {
                material: grass_material.clone(),
                sprite: sprite.clone(),
                transform: Transform::from_translation(translation),
                ..Default::default()
            });
        }
    }
}

pub fn add_player(mut commands: Commands) {
    commands
        .spawn()
        .insert(Player)
        .insert(Name("Player 1".to_string()));
}

pub fn greet_player(
    query: Query<&Name, With<Player>>,
    time: Res<Time>,
    mut timer: ResMut<GreetTimer>,
) {
    if timer.0.tick(time.delta()).just_finished() {
        for name in query.iter() {
            println!("Hello, {}!", name.0);
        }
    }
}
